pub async fn run(args: ExplainArgs, global: &CLIGlobalOptions) -> Result<bool>Expand description
Run the explain command.
Errors
Returns an error if the schema cannot be fetched, parsed, or the pointer cannot be resolved.
pub async fn run(args: ExplainArgs, global: &CLIGlobalOptions) -> Result<bool>Run the explain command.
Returns an error if the schema cannot be fetched, parsed, or the pointer cannot be resolved.