pub struct ExplainArgs {
pub schema: Option<String>,
pub file: Option<String>,
pub resolve_path: Option<String>,
pub cache: CliCacheOptions,
pub no_syntax_highlighting: bool,
pub no_pager: bool,
pub positional: Option<String>,
pub pointer: Option<String>,
}Fields
schema: Option<String>Schema URL or local file path to explain.
Can be combined with --file or --path to override schema resolution
while still validating the data file.
file: Option<String>Data file (local path or URL) to resolve the schema from and validate. The file must exist (or be fetchable). For URLs, the filename is used for catalog matching.
resolve_path: Option<String>File path or URL to resolve the schema from using catalogs. Local files need not exist; if the file exists (or is a URL), it is also validated.
cache: CliCacheOptionsno_syntax_highlighting: boolDisable syntax highlighting in code blocks
no_pager: boolPrint output directly instead of piping through a pager
positional: Option<String>First positional argument. When no --file, --path, or --schema
flag is given this is treated as a file path (equivalent to --path).
Otherwise it is a JSON Pointer or JSONPath to a sub-schema.
Examples:
lintel explain package.json— explains the schema forpackage.jsonlintel explain --file f.yaml name— explains thenameproperty
pointer: Option<String>JSON Pointer (/properties/name) or JSONPath ($.name) to a sub-schema.
Only used when the first positional is a file path.
Example: lintel explain package.json name